# Changelog

## [2.5.4](https://github.com/MONEI/monei-python-sdk/compare/v2.5.3...v2.5.4) (2026-03-30)


### Features

* expose POSAuthTokenApi on MoneiClient ([d822593](https://github.com/MONEI/monei-python-sdk/commit/d822593d310aec337a929a68f93d93297b60c058))

## [2.5.3](https://github.com/MONEI/monei-python-sdk/compare/v2.5.2...v2.5.3) (2026-03-30)

## <small>2.5.2 (2026-01-21)</small>

* chore: update OpenAPI document version to 1.8.3 ([dfc2c93](https://github.com/MONEI/monei-python-sdk/commit/dfc2c93))

## <small>2.5.1 (2025-12-02)</small>

* chore: update OpenAPI document version to 1.8.1 and add new test for Apple Pay certificates response ([1cf7ee3](https://github.com/MONEI/monei-python-sdk/commit/1cf7ee3))

## 2.5.0 (2025-12-01)

* chore: downgrade @release-it/conventional-changelog and update dependencies ([ddef383](https://github.com/MONEI/monei-python-sdk/commit/ddef383))
* chore: update dependencies and package manager ([e9608e4](https://github.com/MONEI/monei-python-sdk/commit/e9608e4))
* feat: add Apple Pay Certificate API and tests ([2d4b715](https://github.com/MONEI/monei-python-sdk/commit/2d4b715))

## 2.4.0 (2025-11-11)

* feat: add Bizum as a payment method to SubscriptionPaymentMethod interface ([767ee36](https://github.com/MONEI/monei-python-sdk/commit/767ee36))

## <small>2.3.8 (2025-11-11)</small>

* chore: update subscription API to include allowed payment methods in requests and responses ([e401c30](https://github.com/MONEI/monei-python-sdk/commit/e401c30))

## <small>2.3.7 (2025-09-15)</small>

* chore: format user agent string for improved readability ([3ca548b](https://github.com/MONEI/monei-python-sdk/commit/3ca548b))
* chore: update package manager to yarn@4.9.4 and enhance user agent format to include Python version ([da1ddea](https://github.com/MONEI/monei-python-sdk/commit/da1ddea))

## <small>2.3.6 (2025-08-27)</small>

* chore: update SDK to OpenAPI specification version 1.7.3 ([9ae0a7e](https://github.com/MONEI/monei-python-sdk/commit/9ae0a7e))

## <small>2.3.5 (2025-08-26)</small>

* chore: update SDK to OpenAPI specification version 1.7.2 ([d5a2a22](https://github.com/MONEI/monei-python-sdk/commit/d5a2a22))

## <small>2.3.4 (2025-05-29)</small>

* chore: update SDK to OpenAPI specification version 1.7.0 ([f8a3180](https://github.com/MONEI/monei-python-sdk/commit/f8a3180))

## <small>2.3.3 (2025-05-28)</small>

* chore: update SDK to OpenAPI specification version 1.6.4 ([ca8ea9b](https://github.com/MONEI/monei-python-sdk/commit/ca8ea9b))
* refactor: streamline imports in README.md ([1f6e88b](https://github.com/MONEI/monei-python-sdk/commit/1f6e88b))

## <small>2.3.2 (2025-04-16)</small>

* chore: update SDK to OpenAPI specification version 1.6.1 ([9a649be](https://github.com/MONEI/monei-python-sdk/commit/9a649be))

## <small>2.3.1 (2025-03-14)</small>

* chore: update SDK to OpenAPI specification version 1.6.0 ([f1214e5](https://github.com/MONEI/monei-python-sdk/commit/f1214e5))
* fix: resolve Black formatter installation issue ([3be582e](https://github.com/MONEI/monei-python-sdk/commit/3be582e))
* test: Add comprehensive model serialization and REST client tests ([7e324a0](https://github.com/MONEI/monei-python-sdk/commit/7e324a0))

## 2.3.0 (2025-03-11)

* feat: Add retry configuration method to MoneiClient ([0440265](https://github.com/MONEI/monei-python-sdk/commit/0440265))
* test: Enhance test coverage for API methods and error handling ([67bbd50](https://github.com/MONEI/monei-python-sdk/commit/67bbd50))

## 2.2.0 (2025-03-11)

* feat: Update SDK to OpenAPI specification version 1.5.8 ([35bd7e1](https://github.com/MONEI/monei-python-sdk/commit/35bd7e1))
* refactor: Simplify signature verification and update commitlint config ([da7bea9](https://github.com/MONEI/monei-python-sdk/commit/da7bea9))

## 2.1.0 (2025-03-08)

* feat: Update SDK to OpenAPI specification version 1.5.7 ([39ace3a](https://github.com/MONEI/monei-python-sdk/commit/39ace3a))
* docs: Remove external documentation link from README ([766db44](https://github.com/MONEI/monei-python-sdk/commit/766db44))
* chore: Add commitlint and conventional changelog configuration ([04fa1f3](https://github.com/MONEI/monei-python-sdk/commit/04fa1f3))

All notable changes to this project will be documented in this file.
